@@ -256,20 +256,6 @@ sub mask_function
 
 return 1;
 
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-OpusVL::Preferences::Schema::Result::PrfDefault
-
-=head1 VERSION
-
-version 0.28
-
 =head1 DESCRIPTION
 
 This table, despite its name, actually holds the field I<definitions> for the
@@ -374,15 +360,4 @@ Provides a subref that will mask values of this field.
     my $mask = $field->mask_function;
     $mask->($value->value);
 
-=head1 AUTHOR
-
-OpusVL - www.opusvl.com
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2011 by OpusVL - www.opusvl.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
